==> haskell-crypto-cipher-types-0.0.9-9-i686.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-cipher-types
version: 0.0.9
id: crypto-cipher-types-0.0.9-Gaasy8ZWU3y7kxB46txgJY
key: crypto-cipher-types-0.0.9-Gaasy8ZWU3y7kxB46txgJY
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-crypto-cipher
synopsis: Generic cryptography cipher types
description:
    Generic cryptography cipher types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules: Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
                Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
                Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
                Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils
abi: 894638411b3dd05c8c44104a49da6323
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/crypto-cipher-types-0.0.9
hs-libraries: HScrypto-cipher-types-0.0.9-Gaasy8ZWU3y7kxB46txgJY
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 securemem-0.1.9-E3A92GFzWR8Jl7bHNv7cPG
haddock-interfaces: /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-cipher-types-0.0.9-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-cipher-types
version: 0.0.9
id: crypto-cipher-types-0.0.9-6q0yWWdZrHZ6FgG0msGljn
key: crypto-cipher-types-0.0.9-6q0yWWdZrHZ6FgG0msGljn
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-crypto-cipher
synopsis: Generic cryptography cipher types
description:
    Generic cryptography cipher types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules: Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
                Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
                Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
                Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils
abi: 752cc724af244d84f1881b956be4c996
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/crypto-cipher-types-0.0.9
hs-libraries: HScrypto-cipher-types-0.0.9-6q0yWWdZrHZ6FgG0msGljn
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 securemem-0.1.9-BEpNQw6mkLfDLYCyNkxHXF
haddock-interfaces: /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
